import { useState, useRef } from 'react';
import { Button, Popconfirm, Modal, Form, Input, message, Tree, Row, Col, Divider } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';
import moment from 'moment';
import { getList, update } from '@/services/feedback'

const formatterTime = (val) => {
  return val && val !== '-' ? moment(val).format('YYYY-MM-DD') : '-';
};
const FormItem = Form.Item;
const { TextArea } = Input;

export default () => {
  const actionRef = useRef();
  const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
  const [current, setCurrent] = useState()
  const [show, setShow] = useState(false)
  const [loading, setLoading] = useState(false)
  const showModel = (val) => {
    setShow(true)
    setCurrent(val)
  }
  const onchange = (e) => {
    setCurrent({ ...current, result: e.target.value })
  }
  const onCancel = () => {
    setShow(false)
    setCurrent()
  }
  const Submit = () => {
    if (!current.result) {
      message.info(`请输入处理结果`);
      return
    }
    setLoading(true)
    update(current.feedbackId, { ...current, status: 1 }).then(() => {
      message.success('处理成功')
      onCancel()
      setLoading(false)
      actionRef.current.reload();
    }).catch((err) => {
      setLoading(false);
      message.error(err.message || err);
    });
  }

  const columns = [
    {
      title: '反馈人',
      dataIndex: 'nickName',
      key: 'nickName',
    },
    {
      title: '电话',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '反馈内容',
      dataIndex: 'content',
      key: 'content',
      ellipsis: true,
    },
    {
      title: '创建时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: formatterTime,
      width: 160,
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 100,
      render: (_, record) => {
        return record.status === 1 ? '已处理' : '未处理';
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Button key={1} style={{ padding: 0 }} type="link" onClick={() => showModel(record)}>
          处理
        </Button>,
      ],
    },
  ];
  return (
    <PageHeaderWrapper>
      <PageTable
        request={getList}
        columns={columns}
        actionRef={actionRef}
        rowKey="feedbackId"
        options={false}
        search={false}
        scroll={{ x: 1000 }}
      />
      <Modal
        forceRender
        title='意见反馈'
        visible={show}
        onCancel={onCancel}
        keyboard={false}
        maskClosable={false}
        destroyOnClose={true}
        footer={null}
      >
        <Form {...formItemLayout} >
          <FormItem label="角色名" >
            {current?.nickName}
          </FormItem>
          <FormItem label="电话" >
            {current?.phone}
          </FormItem>
          <FormItem label="反馈内容" >
            {current?.content}
          </FormItem>
          <FormItem label="处理结果" >
            <TextArea placeholder="请输入" value={current?.result} onInput={onchange} />
          </FormItem>
          <FormItem label=" " colon={false}>
            <Button type="default" onClick={onCancel}>
              取消
            </Button>
            <Button
              type="primary"
              loading={loading}
              style={{ marginLeft: '4em' }}
              onClick={Submit}
            >
              确认
            </Button>
          </FormItem>
        </Form>
      </Modal>
    </PageHeaderWrapper>
  )
}